import {
  csvParse,
  select,
  min,
  max,
  extent,
  group,
  flatGroup,
  rollup,
  flatRollup,
  sum,
  bin,
} from 'd3';

export const viz = (
  container,
  { state, setState }
) => {
  if (state.data && state.data !== 'LOADING') {
    const data = state.data;

    const group = flatGroup(data, (d) =>
      d.Nationality.split(' ')[0].replace(
        /[{()}]/g,
        ''
      )
    ).map(([key, value]) => ({
      medium: key,
      count: value.length,
    }));
    const summary = group
      .slice()
      .sort((a, b) =>
        d3.descending(a.count, b.count)
      );

    select(container)
      .selectAll('pre')
      .data([null])
      .join('pre')
      .text(JSON.stringify(summary, null, 2));
  }

  function getCountryCode(nationality) {
    fetch(
      `https://restcountries.com/v3.1/name/${nationality}?fullText=true`
    )
      .then((response) => response.json())
      .then((data) => {
        // Get the country code from the response data
        const countryCode = data[0].alpha2Code;
        console.log(countryCode);
      })
      .catch((error) => console.error(error));
  }

  console.log(getCountryCode("American"))
  
  // state.data could be:
  // * undefined
  // * 'LOADING'
  // * An array of objects
  const { data } = state;

  if (data === undefined) {
    setState((state) => ({
      ...state,
      data: 'LOADING',
    }));
    fetch('data.csv')
      .then((response) => response.text())
      .then((csvString) => {
        const data = csvParse(csvString);

        for (const d of data) {
          d.BeginDate = +d.BeginDate * -1;
          d.EndDate = +d.EndDate * -1;
          d.Date = +d.Date;
          d.ObjectID = +d.ObjectID;
          if (+d.Circumference == 0) {
            d.Circumference = null;
          } else {
            d.Circumference = +d.Circumference;
          }

          if (+d.Depth == 0) {
            d.Depth = null;
          } else {
            d.Depth = +d.Depth;
          }

          if (+d.Diameter == 0) {
            d.Diameter = null;
          } else {
            d.Diameter = +d.Diameter;
          }

          if (+d.Height == 0) {
            d.Height = null;
          } else {
            d.Height = +d.Height;
          }

          if (+d.Length == 0) {
            d.Length = null;
          } else {
            d.Length = +d.Length;
          }

          if (+d.Weight == 0) {
            d.Weight = null;
          } else {
            d.Weight = +d.Weight;
          }

          if (+d.Width == 0) {
            d.Width = null;
          } else {
            d.Width = +d.Width;
          }

          if (+d.SeatHeight == 0) {
            d.SeatHeight = null;
          } else {
            d.SeatHeight = +d.SeatHeight;
          }

          if (+d.Duration == 0) {
            d.Duration = null;
          } else {
            d.Duration = +d.Duration;
          }
        }

        setState((state) => ({
          ...state,
          data,
        }));
      });
  }
};
